@@ -113,7 +113,8 @@ $TMPL = {
     backend         => { default => '' },
     term            => { default => '' },
     format          => { default => '' },
-    remote          => { default => {} },
+    remote          => { default => undef },
+    noninteractive  => { default => '' },
     cache           => { default => [ ] },
     _old_sigpipe    => { default => '', no_override => 1 },
     _old_outfh      => { default => '', no_override => 1 },
